package cn.com.infosec.asn1;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.SimpleTimeZone;
import java.util.TimeZone;

public class DERGeneralizedTime extends ASN1Object {
   String time;

   public static DERGeneralizedTime getInstance(Object obj) {
      if (obj != null && !(obj instanceof DERGeneralizedTime)) {
         if (obj instanceof ASN1OctetString) {
            return new DERGeneralizedTime(((ASN1OctetString)obj).getOctets());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (DERGeneralizedTime)obj;
      }
   }

   public static DERGeneralizedTime getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   public DERGeneralizedTime(String time) {
      DERGeneralizedTime var10000 = this;
      super();
      this.time = time;

      try {
         var10000.getDate();
      } catch (ParseException var2) {
         throw new IllegalArgumentException("invalid date string: " + var2.getMessage());
      }

   }

   public DERGeneralizedTime(Date time) {
      SimpleDateFormat var10001 = new SimpleDateFormat("yyyyMMddHHmmss'Z'");
      var10001.setTimeZone(new SimpleTimeZone(0, "Z"));
      this.time = var10001.format(time);
   }

   DERGeneralizedTime(byte[] bytes) {
      int var2;
      char[] var3 = new char[var2 = bytes.length];

      for(int var4 = 0; var4 != var2; ++var4) {
         var3[var4] = (char)(bytes[var4] & 255);
      }

      String var5;
      var5 = new String.<init>(var3);
      this.time = var5;
   }

   private String calculateGMTOffset() {
      String var1 = "+";
      TimeZone var2;
      int var3;
      if ((var3 = (var2 = TimeZone.getDefault()).getRawOffset()) < 0) {
         var1 = "-";
         var3 = -var3;
      }

      TimeZone var10000 = var2;
      int var4 = (var3 - (var3 /= 3600000) * 60 * 60 * 1000) / '\uea60';

      boolean var10001;
      boolean var9;
      try {
         var9 = var10000.useDaylightTime();
      } catch (ParseException var7) {
         var10001 = false;
         return "GMT" + var1 + this.convert(var3) + ":" + this.convert(var4);
      }

      if (var9) {
         try {
            var9 = var2.inDaylightTime(this.getDate());
         } catch (ParseException var6) {
            var10001 = false;
            return "GMT" + var1 + this.convert(var3) + ":" + this.convert(var4);
         }

         if (!var9) {
            return "GMT" + var1 + this.convert(var3) + ":" + this.convert(var4);
         }

         try {
            var9 = var1.equals("+");
         } catch (ParseException var5) {
            var10001 = false;
            return "GMT" + var1 + this.convert(var3) + ":" + this.convert(var4);
         }

         byte var8;
         if (var9) {
            var8 = 1;
         } else {
            var8 = -1;
         }

         var3 += var8;
      }

      return "GMT" + var1 + this.convert(var3) + ":" + this.convert(var4);
   }

   private String convert(int time) {
      return time < 10 ? "0" + time : Integer.toString(time);
   }

   private boolean hasFractionalSeconds() {
      return this.time.indexOf(46) == 14;
   }

   private byte[] getOctets() {
      char[] var3;
      byte[] var1 = new byte[(var3 = this.time.toCharArray()).length];

      for(int var2 = 0; var2 != var3.length; ++var2) {
         var1[var2] = (byte)var3[var2];
      }

      return var1;
   }

   public String getTimeString() {
      return this.time;
   }

   public String getTime() {
      String var10000 = this.time;
      if (var10000.charAt(var10000.length() - 1) == 'Z') {
         String var10002 = this.time;
         return var10002.substring(0, var10002.length() - 1) + "GMT+00:00";
      } else {
         int var1 = this.time.length() - 5;
         char var2;
         if ((var2 = this.time.charAt(var1)) != '-' && var2 != '+') {
            var1 = this.time.length() - 3;
            return (var2 = this.time.charAt(var1)) != '-' && var2 != '+' ? this.time + this.calculateGMTOffset() : this.time.substring(0, var1) + "GMT" + this.time.substring(var1) + ":00";
         } else {
            return this.time.substring(0, var1) + "GMT" + this.time.substring(var1, var1 += 3) + ":" + this.time.substring(var1);
         }
      }
   }

   public Date getDate() {
      String var1;
      SimpleTimeZone var2;
      SimpleDateFormat var3;
      if ((var1 = this.time).endsWith("Z")) {
         if (this.hasFractionalSeconds()) {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmss.SSSS'Z'");
         } else {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmss'Z'");
         }

         var2 = new SimpleTimeZone.<init>(0, "Z");
         var3.setTimeZone(var2);
      } else if (this.time.indexOf(45) <= 0 && this.time.indexOf(43) <= 0) {
         if (this.hasFractionalSeconds()) {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmss.SSSS");
         } else {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmss");
         }

         var3.setTimeZone(new SimpleTimeZone(0, TimeZone.getDefault().getID()));
      } else {
         var1 = this.getTime();
         if (this.hasFractionalSeconds()) {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmss.SSSSz");
         } else {
            var3 = new SimpleDateFormat.<init>("yyyyMMddHHmmssz");
         }

         var2 = new SimpleTimeZone.<init>(0, "Z");
         var3.setTimeZone(var2);
      }

      return var3.parse(var1);
   }

   void encode(DEROutputStream out) {
      out.writeEncoded(24, this.getOctets());
   }

   boolean asn1Equals(DERObject o) {
      return !(o instanceof DERGeneralizedTime) ? false : this.time.equals(((DERGeneralizedTime)o).time);
   }

   public int hashCode() {
      return this.time.hashCode();
   }
}
